@@ -1,7 +1,6 @@
 # -*- coding:utf-8 -*-
 import csv
-from sylk import SYLK
-import io
+from sylk_parser.sylk import SYLK
 
 SYLK_CHARSET = "cp1252"
 
@@ -13,15 +12,13 @@ class SylkParser:
         filename,
         headers=None,
         encoding=SYLK_CHARSET,
-        use_unicode=False,
     ):
         if headers is None:
             headers = []
 
         self.headers = headers
         self.sylk_handler = SYLK()
-        self.use_unicode = use_unicode
-        with io.open(filename, encoding=encoding) as handle:
+        with open(filename, encoding=encoding) as handle:
             self.sylk_handler.parse(handle)
 
     def to_csv(self, fbuf, quotechar='"', delimiter=','):
@@ -49,9 +46,6 @@ class SylkParser:
 
     def __iter__(self):
         for line in self.sylk_handler.stream_rows():
-            if self.use_unicode:
-                line = [a.decode('utf-8') for a in line]
-
             if self.headers:
                 yield dict(zip(self.headers, line))
             else:
